// multirgb.wdl


// entSkin1   Texture Base
// entSkin2   Texture Layer Red

bmap tex1 = <gras.bmp>; 		// RGB Mask
bmap tex4 = <road.bmp>; 		// Texture Layer Green
bmap tex5 = <sand.bmp>; 		// Texture Layer Blue
bmap tex6 = <detailmap.tga>; 	// DetailMap

function multirgb_roughness() {	
	bmap_to_mipmap(mtl.Skin1);
	bmap_to_mipmap(mtl.Skin2);
	bmap_to_mipmap(mtl.Skin3);
	bmap_to_mipmap(mtl.Skin4);
}

material multirgb {
	flags = tangent;
	skin1 = tex1;
	skin2 = tex4;
	skin3 = tex5;
	skin4 = tex6;

	event=multirgb_roughness;
	
	effect
	"
		//////////////////////////////////////////////////////////////////////////////////////////////////////
		// Define your needed values
		float4x4 matWorldViewProj;			// 
	
		float4x4 matWorld;	
		float4x4 matWorldInv;	
		float4x4 matWorldView;
	
		float4 vecFog;
		
		// Define your textures
		texture mtlSkin1;					
		texture mtlSkin2;					
		texture mtlSkin3;					
		texture mtlSkin4;					
		texture entSkin1;					
		texture entSkin2;					
		
		//////////////////////////////////////////////////////////////////////////////////////////////////////
		// Texture settings
		sampler sTex1 = sampler_state			
		{
			Texture = <entSkin2>;   // RGB Mask
			MipFilter = Linear;
			MinFilter = Linear;
			MagFilter = Linear;
			AddressU = Wrap;	
			AddressV = Wrap;
		};
		sampler sTex2 = sampler_state			
		{
			Texture = <entSkin1>;   // Texture Base
			MipFilter = Linear;
			MinFilter = Linear;
			MagFilter = Linear;
			AddressU = Wrap;	
			AddressV = Wrap;
		};
		sampler sTex3 = sampler_state			
		{
			Texture = <mtlSkin1>;	// Texture Layer Red
			MipFilter = Linear;
			MinFilter = Linear;
			MagFilter = Linear;
			AddressU = Wrap;	
			AddressV = Wrap;
		};
		sampler sTex4 = sampler_state			
		{
			Texture = <mtlSkin2>;	// Texture Layer Green
			MipFilter = Linear;
			MinFilter = Linear;
			MagFilter = Linear;
			AddressU = Wrap;	
			AddressV = Wrap;
		};
		sampler sTex5 = sampler_state			
		{
			Texture = <mtlSkin3>;	// Texture Layer Blue
			MipFilter = Linear;
			MinFilter = Linear;
			MagFilter = Linear;
			AddressU = Wrap;	
			AddressV = Wrap;
		};
		sampler sTex6 = sampler_state			
		{
			Texture = <mtlSkin4>;	// Detailmap for Base Texture
			MipFilter = Linear;
			MinFilter = Linear;
			MagFilter = Linear;
			AddressU = Wrap;	
			AddressV = Wrap;
		};

		
				
		struct TMULTI_VS_OUT // Output to the pixelshader fragment
		{
			float4 Pos 		: POSITION;
			float  Fog		: FOG;
			float2 Tex1 	: TEXCOORD0;
			float2 Tex2 	: TEXCOORD1;
			float2 Tex3 	: TEXCOORD2;
			float2 Tex4		: TEXCOORD3;
			float2 Tex5		: TEXCOORD5;
			float2 Tex6		: TEXCOORD6;
		};


		float DoFog(float4 Pos)	{
			float3 P = mul(Pos,matWorldView);// apply the linear fog formula   		
			return saturate((vecFog.y-P.z) * vecFog.z);	
		}

		TMULTI_VS_OUT TMulti_VS(
		float4 inPos : POSITION,
		float3 inNormal : NORMAL,
		float2 inTexCoord0 : TEXCOORD0)
		{
			TMULTI_VS_OUT Out;
			
			// transform the vector position to screen coordinates
			Out.Pos = mul(inPos,matWorldViewProj);
			
			// rotate and normalize the normal
			float3 N = normalize(mul(inNormal,matWorldInv));

			Out.Fog = DoFog(inPos);
			
			// scale the texture coordinates for the masked textures
			Out.Tex1  = inTexCoord0.xy;		// Tile Mask
			Out.Tex2  = inTexCoord0.xy;		// Tile Base Texture
			Out.Tex3  = inTexCoord0.xy*20;	// Tile Texture Layer Red
			Out.Tex4  = inTexCoord0.xy*20;	// Tile Texture Layer Green
			Out.Tex5  = inTexCoord0.xy*20;	// Tile Texture Layer Blue
			Out.Tex6  = inTexCoord0.xy*20;	// Tile Texture Layer Detailmap
			return Out;
		}
		
		
		//////////////////////////////////////////////////////////////////////////////////////////////////////
		// pixelshader
		float4 ps( TMULTI_VS_OUT In ) : COLOR
		{
			float4 MaskColor = tex2D(sTex1,In.Tex1);
			float4 BaseColor = tex2D(sTex2,In.Tex2);
			float4 RedColor = tex2D(sTex3,In.Tex3);
			float4 GreenColor = tex2D(sTex4,In.Tex4);
			float4 BlueColor = tex2D(sTex5,In.Tex5);
			float4 DetailColor = tex2D(sTex6,In.Tex5);
			
			BaseColor = BaseColor + DetailColor - 0.5;
			
			float4 BaseRed = lerp(BaseColor,RedColor,MaskColor.r);
			float4 BaseGreen = lerp(BaseRed,GreenColor,MaskColor.g);
			float4 FinalColor = lerp(BaseGreen,BlueColor,MaskColor.b);
			
			FinalColor.a = 1.0f; // prevent transparency
			
			return FinalColor;
		}
	
		//////////////////////////////////////////////////////////////////////////////////////////////////////
		// 
		technique mytechnique
		{
			// Define your passes
			pass p0
			{				
				VertexShader = compile vs_2_0 TMulti_VS();
				PixelShader = compile ps_2_0 ps();
			}
		}
	";
}

ACTION multi_rgb {
	my.material=multirgb;
}



function fog() {
	fog_color = 1;
	camera.fog_start = 5000;
	camera.fog_end = 8000;
	camera.clip_far = 25000;
}


Function Main() {	
	level_load("multirgb.wmb");
}

on_1 fog();